@@ -52,6 +52,8 @@ int ViewManager::lastManagerId = 0;
 ViewManager::ViewManager(QObject *parent, KActionCollection *collection) :
     QObject(parent),
     _viewSplitter(nullptr),
+    _pluggedController(nullptr),
+    _sessionMap(QHash<TerminalDisplay *, Session *>()),
     _actionCollection(collection),
     _navigationMethod(TabbedNavigation),
     _navigationVisibility(ViewContainer::AlwaysShowNavigation),
@@ -400,7 +402,7 @@ void ViewManager::sessionFinished()
 {
     // if this slot is called after the view manager's main widget
     // has been destroyed, do nothing
-    if (_viewSplitter == nullptr) {
+    if (_viewSplitter.isNull()) {
         return;
     }
 
@@ -420,7 +422,7 @@ void ViewManager::sessionFinished()
     // Only remove the controller from factory() if it's actually controlling
     // the session from the sender.
     // This fixes BUG: 348478 - messed up menus after a detached tab is closed
-    if ((_pluggedController != nullptr) && (_pluggedController->session() == session)) {
+    if ((!_pluggedController.isNull()) && (_pluggedController->session() == session)) {
         // This is needed to remove this controller from factory() in
         // order to prevent BUG: 185466 - disappearing menu popup
         emit unplugController(_pluggedController);
@@ -548,7 +550,7 @@ SessionController *ViewManager::createController(Session *session, TerminalDispl
             &Konsole::SessionController::deleteLater);
 
     // if this is the first controller created then set it as the active controller
-    if (_pluggedController == nullptr) {
+    if (_pluggedController.isNull()) {
         controllerChanged(controller);
     }
 
@@ -652,22 +654,12 @@ void ViewManager::createView(Session *session)
 
 ViewContainer *ViewManager::createContainer()
 {
-    ViewContainer *container = nullptr;
 
-    switch (_navigationMethod) {
-    case TabbedNavigation:
-    {
-        auto tabbedContainer = new TabbedViewContainer(_navigationPosition, this, _viewSplitter);
-        container = tabbedContainer;
-
-        connect(tabbedContainer, &TabbedViewContainer::detachTab, this, &ViewManager::detachView);
-        connect(tabbedContainer, &TabbedViewContainer::closeTab, this,
+    auto *container = new TabbedViewContainer(_navigationPosition, this, _viewSplitter);
+    if (_navigationMethod == TabbedNavigation) {
+        connect(container, &TabbedViewContainer::detachTab, this, &ViewManager::detachView);
+        connect(container, &TabbedViewContainer::closeTab, this,
                 &ViewManager::closeTabFromContainer);
-        break;
-    }
-    case NoNavigation:
-    default:
-        container = new StackedViewContainer(_viewSplitter);
     }
 
     // FIXME: these code feels duplicated
@@ -675,15 +667,7 @@ ViewContainer *ViewManager::createContainer()
     container->setNavigationPosition(_navigationPosition);
     container->setNavigationTabWidthExpanding(_navigationTabWidthExpanding);
     container->setStyleSheet(_navigationStyleSheet);
-    if (_showQuickButtons) {
-        container->setFeatures(container->features()
-                               | ViewContainer::QuickNewView
-                               | ViewContainer::QuickCloseView);
-    } else {
-        container->setFeatures(container->features()
-                               & ~ViewContainer::QuickNewView
-                               & ~ViewContainer::QuickCloseView);
-    }
+    setContainerFeatures(container);
 
     // connect signals and slots
     connect(container, &Konsole::ViewContainer::viewAdded, this,
@@ -710,6 +694,10 @@ ViewContainer *ViewManager::createContainer()
     connect(container, &Konsole::ViewContainer::activeViewChanged, this,
             &Konsole::ViewManager::viewActivated);
 
+    if (_navigationMethod != TabbedNavigation) {
+        container->setTabBarVisible(false);
+    }
+
     return container;
 }
 
@@ -764,47 +752,22 @@ void ViewManager::setNavigationMethod(NavigationMethod method)
     // by using a separate action collection.
 
     const bool enable = (_navigationMethod != NoNavigation);
-    QAction *action;
 
-    action = collection->action(QStringLiteral("next-view"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
+    auto enableAction = [&enable, &collection](const QString& actionName) {
+        auto *action = collection->action(actionName);
+        if (action != nullptr) {
+            action->setEnabled(enable);
+        }
+    };
 
-    action = collection->action(QStringLiteral("previous-view"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
-
-    action = collection->action(QStringLiteral("last-tab"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
-
-    action = collection->action(QStringLiteral("split-view-left-right"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
-
-    action = collection->action(QStringLiteral("split-view-top-bottom"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
-
-    action = collection->action(QStringLiteral("rename-session"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
-
-    action = collection->action(QStringLiteral("move-view-left"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
-
-    action = collection->action(QStringLiteral("move-view-right"));
-    if (action != nullptr) {
-        action->setEnabled(enable);
-    }
+    enableAction(QStringLiteral("next-view"));
+    enableAction(QStringLiteral("previous-view"));
+    enableAction(QStringLiteral("last-tab"));
+    enableAction(QStringLiteral("split-view-left-right"));
+    enableAction(QStringLiteral("split-view-top-bottom"));
+    enableAction(QStringLiteral("rename-session"));
+    enableAction(QStringLiteral("move-view-left"));
+    enableAction(QStringLiteral("move-view-right"));
 }
 
 ViewManager::NavigationMethod ViewManager::navigationMethod() const
@@ -814,7 +777,7 @@ ViewManager::NavigationMethod ViewManager::navigationMethod() const
 
 void ViewManager::containerViewsChanged(ViewContainer *container)
 {
-    if ((_viewSplitter != nullptr) && container == _viewSplitter->activeContainer()) {
+    if ((!_viewSplitter.isNull()) && container == _viewSplitter->activeContainer()) {
         emit viewPropertiesChanged(viewProperties());
     }
 }
@@ -836,7 +799,7 @@ void ViewManager::viewDestroyed(QWidget *view)
         }
     }
     //we only update the focus if the splitter is still alive
-    if (_viewSplitter != nullptr) {
+    if (!_viewSplitter.isNull()) {
         updateDetachViewState();
     }
     // The below causes the menus  to be messed up
@@ -893,18 +856,8 @@ void ViewManager::applyProfileToView(TerminalDisplay *view, const Profile::Ptr p
     view->setVTFont(profile->font());
 
     // set scroll-bar position
-    int scrollBarPosition = profile->property<int>(Profile::ScrollBarPosition);
-
-    if (scrollBarPosition == Enum::ScrollBarLeft) {
-        view->setScrollBarPosition(Enum::ScrollBarLeft);
-    } else if (scrollBarPosition == Enum::ScrollBarRight) {
-        view->setScrollBarPosition(Enum::ScrollBarRight);
-    } else if (scrollBarPosition == Enum::ScrollBarHidden) {
-        view->setScrollBarPosition(Enum::ScrollBarHidden);
-    }
-
-    bool scrollFullPage = profile->property<bool>(Profile::ScrollFullPage);
-    view->setScrollFullPage(scrollFullPage);
+    view->setScrollBarPosition(Enum::ScrollBarPositionEnum(profile->property<int>(Profile::ScrollBarPosition)));
+    view->setScrollFullPage(profile->property<bool>(Profile::ScrollFullPage));
 
     // show hint about terminal size after resizing
     view->setShowTerminalSizeHint(profile->showTerminalSizeHint());
@@ -912,10 +865,7 @@ void ViewManager::applyProfileToView(TerminalDisplay *view, const Profile::Ptr p
     // terminal features
     view->setBlinkingCursorEnabled(profile->blinkingCursorEnabled());
     view->setBlinkingTextEnabled(profile->blinkingTextEnabled());
-
-    int tripleClickMode = profile->property<int>(Profile::TripleClickMode);
-    view->setTripleClickMode(Enum::TripleClickModeEnum(tripleClickMode));
-
+    view->setTripleClickMode(Enum::TripleClickModeEnum(profile->property<int>(Profile::TripleClickMode)));
     view->setAutoCopySelectedText(profile->autoCopySelectedText());
     view->setControlDrag(profile->property<bool>(Profile::CtrlRequiredForDrag));
     view->setDropUrlsAsText(profile->property<bool>(Profile::DropUrlsAsText));
@@ -923,18 +873,9 @@ void ViewManager::applyProfileToView(TerminalDisplay *view, const Profile::Ptr p
     view->setLineSpacing(profile->lineSpacing());
     view->setTrimLeadingSpaces(profile->property<bool>(Profile::TrimLeadingSpacesInSelectedText));
     view->setTrimTrailingSpaces(profile->property<bool>(Profile::TrimTrailingSpacesInSelectedText));
-
     view->setOpenLinksByDirectClick(profile->property<bool>(Profile::OpenLinksByDirectClickEnabled));
-
     view->setUrlHintsModifiers(profile->property<int>(Profile::UrlHintsModifiers));
-
-    int middleClickPasteMode = profile->property<int>(Profile::MiddleClickPasteMode);
-    if (middleClickPasteMode == Enum::PasteFromX11Selection) {
-        view->setMiddleClickPasteMode(Enum::PasteFromX11Selection);
-    } else if (middleClickPasteMode == Enum::PasteFromClipboard) {
-        view->setMiddleClickPasteMode(Enum::PasteFromClipboard);
-    }
-
+    view->setMiddleClickPasteMode(Enum::MiddleClickPasteModeEnum(profile->property<int>(Profile::MiddleClickPasteMode)));
     view->setCopyTextAsHTML(profile->property<bool>(Profile::CopyTextAsHTML));
 
     // margin/center
@@ -942,25 +883,12 @@ void ViewManager::applyProfileToView(TerminalDisplay *view, const Profile::Ptr p
     view->setCenterContents(profile->property<bool>(Profile::TerminalCenter));
 
     // cursor shape
-    int cursorShape = profile->property<int>(Profile::CursorShape);
-
-    if (cursorShape == Enum::BlockCursor) {
-        view->setKeyboardCursorShape(Enum::BlockCursor);
-    } else if (cursorShape == Enum::IBeamCursor) {
-        view->setKeyboardCursorShape(Enum::IBeamCursor);
-    } else if (cursorShape == Enum::UnderlineCursor) {
-        view->setKeyboardCursorShape(Enum::UnderlineCursor);
-    }
+    view->setKeyboardCursorShape(Enum::CursorShapeEnum(profile->property<int>(Profile::CursorShape)));
 
     // cursor color
-    if (profile->useCustomCursorColor()) {
-        const QColor &cursorColor = profile->customCursorColor();
-        view->setKeyboardCursorColor(cursorColor);
-    } else {
-        // an invalid QColor is used to inform the view widget to
-        // draw the cursor using the default color( matching the text)
-        view->setKeyboardCursorColor(QColor());
-    }
+    // an invalid QColor is used to inform the view widget to
+    // draw the cursor using the default color( matching the text)
+    view->setKeyboardCursorColor(profile->useCustomCursorColor() ? profile->customCursorColor() : QColor());
 
     // word characters
     view->setWordCharacters(profile->wordCharacters());
@@ -970,6 +898,7 @@ void ViewManager::applyProfileToView(TerminalDisplay *view, const Profile::Ptr p
 
     // mouse wheel zoom
     view->setMouseWheelZoom(profile->mouseWheelZoomEnabled());
+    view->setAlternateScrolling(profile->property<bool>(Profile::AlternateScrolling));
 }
 
 void ViewManager::updateViewsForSession(Session *session)
@@ -1098,7 +1027,7 @@ void ViewManager::restoreSessions(const KConfigGroup &group)
 
 int ViewManager::sessionCount()
 {
-    return this->_sessionMap.size();
+    return _sessionMap.size();
 }
 
 QStringList ViewManager::sessionList()
@@ -1144,7 +1073,7 @@ int ViewManager::newSession()
 
     session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
 
-    this->createView(session);
+    createView(session);
     session->run();
 
     return session->sessionId();
@@ -1166,7 +1095,7 @@ int ViewManager::newSession(const QString &profile)
 
     session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
 
-    this->createView(session);
+    createView(session);
     session->run();
 
     return session->sessionId();
@@ -1189,7 +1118,7 @@ int ViewManager::newSession(const QString &profile, const QString &directory)
 
     session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
 
-    this->createView(session);
+    createView(session);
     session->run();
 
     return session->sessionId();
@@ -1207,22 +1136,22 @@ QStringList ViewManager::profileList()
 
 void ViewManager::nextSession()
 {
-    this->nextView();
+    nextView();
 }
 
 void ViewManager::prevSession()
 {
-    this->previousView();
+    previousView();
 }
 
 void ViewManager::moveSessionLeft()
 {
-    this->moveActiveViewLeft();
+    moveActiveViewLeft();
 }
 
 void ViewManager::moveSessionRight()
 {
-    this->moveActiveViewRight();
+    moveActiveViewRight();
 }
 
 void ViewManager::setTabWidthToText(bool useTextWidth)
@@ -1278,20 +1207,24 @@ void ViewManager::setNavigationStyleSheet(const QString &styleSheet)
     }
 }
 
+void ViewManager::setContainerFeatures(ViewContainer *container)
+{
+    if (_showQuickButtons) {
+        container->setFeatures(container->features()
+                               | ViewContainer::QuickNewView
+                               | ViewContainer::QuickCloseView);
+    } else {
+        container->setFeatures(container->features()
+                               & ~ViewContainer::QuickNewView
+                               & ~ViewContainer::QuickCloseView);
+    }
+}
 void ViewManager::setShowQuickButtons(bool show)
 {
     _showQuickButtons = show;
 
-    foreach (ViewContainer *container, _viewSplitter->containers()) {
-        if (_showQuickButtons) {
-            container->setFeatures(container->features()
-                                   | ViewContainer::QuickNewView
-                                   | ViewContainer::QuickCloseView);
-        } else {
-            container->setFeatures(container->features()
-                                   & ~ViewContainer::QuickNewView
-                                   & ~ViewContainer::QuickCloseView);
-        }
+    for (auto *container : _viewSplitter->containers()) {
+        setContainerFeatures(container);
     }
 }
 
