@@ -75,7 +75,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
         needToDeleteQApplication = true;
     }
 
-#if defined(Q_OS_LINUX)
+#if defined(Q_OS_LINUX) && (QT_VERSION < QT_VERSION_CHECK(5, 11, 2))
     // Workaround for https://bugreports.qt.io/browse/QTBUG-48344
     // See also https://bugs.kde.org/show_bug.cgi?id=230184
     // The Qt glib event loop doesn't let timers deliver events if there are a
@@ -86,7 +86,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
 
     auto app = new QApplication(argc, argv);
 
-#if defined(Q_OS_LINUX)
+#if defined(Q_OS_LINUX) && (QT_VERSION < QT_VERSION_CHECK(5, 11, 2))
     if (qtUseGLibOld.isNull()) {
         qunsetenv("QT_NO_GLIB");
     } else {
